@@ -36,19 +36,19 @@ bzr vcs support.
 New in ROS C-Turtle.
 """
 
-from __future__ import with_statement
 import subprocess
 import os
 import sys
-import vcs_base
 import urllib
 
-class BZRClient(vcs_base.VCSClientBase):
+from  .vcs_base import VcsClientBase
+
+class BzrClient(VcsClientBase):
     def __init__(self, path):
         """
         Raise LookupError if bzr not detected
         """
-        vcs_base.VCSClientBase.__init__(self, path)
+        VcsClientBase.__init__(self, 'bzr', path)
         with open(os.devnull, 'w') as fnull:
             try:
                 subprocess.call("bzr help".split(), stdout=fnull, stderr=fnull)
@@ -69,7 +69,6 @@ class BZRClient(vcs_base.VCSClientBase):
     def detect_presence(self):
         return self.path_exists() and os.path.isdir(os.path.join(self._path, '.bzr'))
 
-
     def checkout(self, url, version=''):
         if self.path_exists():
             sys.stderr.write("Error: cannot checkout into existing directory\n")
@@ -94,10 +93,6 @@ class BZRClient(vcs_base.VCSClientBase):
                 return True
         return False
 
-    def get_vcs_type_name(self):
-        return 'bzr'
-
-
     def get_version(self, spec=None):
         """
         @param spec: (optional) revisionspec of desired version.  May
@@ -122,32 +117,37 @@ class BZRClient(vcs_base.VCSClientBase):
                 output = subprocess.Popen(['bzr', 'revno'], cwd= self._path, stdout=subprocess.PIPE).communicate()[0]
                 return output.strip()
 
-
-class BZRConfig(object):
-    """
-    Configuration information about an BZR repository for a component
-    of code. The configuration we maintain is specific to ROS
-    toolchain concepts and is not a general notion of BZR configuration.
-    
-     * repo_uri: base URI of repo
-     * dev_branch: hg branch the code is developed
-     * distro_tag: a tag of the latest released code for a specific ROS distribution
-     * release_tag: a tag of the code for a specific release
-     """
-
-    def __init__(self):
-        self.type = 'bzr'
-        self.repo_uri      = None
-        self.anon_repo_uri = None
-        self.dev_branch    = None
-        self.distro_tag    = None
-        self.release_tag   = None
-
-    def __eq__(self, other):
-        return self.repo_uri == other.repo_uri and \
-            self.anon_repo_uri == other.anon_repo_uri and \
-            self.dev_branch == other.dev_branch and \
-            self.release_tag == other.release_tag and \
-            self.distro_tag == other.distro_tag
+    def get_diff(self, basepath=None):
+        response = None
+        if basepath == None:
+            basepath = self._path
+        if self.path_exists():
+            rel_path = self._normalized_rel_path(self._path, basepath)
+            command = "cd %s; bzr diff %s"%(basepath, rel_path)
+            command += " -p1 --prefix %s/:%s/"%(rel_path,rel_path)
+            stdout_handle = os.popen(command, "r")
+            response = stdout_handle.read()
+        if response != None and response.strip() == '':
+            response = None
+        return response
 
 
+    def get_status(self, basepath=None, untracked=False):
+        response=None
+        if basepath == None:
+            basepath = self._path
+        if self.path_exists():
+            rel_path = self._normalized_rel_path(self._path, basepath)
+            command = "cd %s; bzr status %s -S"%(basepath, rel_path)
+            if not untracked:
+                command += " -V"
+            stdout_handle = os.popen(command, "r")
+            response = stdout_handle.read()
+            response_processed = ""
+            for line in response.split('\n'):
+                if len(line.strip()) > 0:
+                    response_processed+=line[0:4]+rel_path+'/'+line[4:]+'\n'
+            response = response_processed
+        return response
+
+BZRClient=BzrClient
