@@ -32,22 +32,20 @@
 #
 """
 svn vcs support.
-
-New in ROS C-Turtle.
 """
-from __future__ import with_statement
 
 import os
 import sys
 import subprocess
-import vcs_base
+from .vcs_base import VcsClientBase
+
+class SvnClient(VcsClientBase):
 
-class SVNClient(vcs_base.VCSClientBase):
     def __init__(self, path):
         """
         Raise LookupError if svn not detected
         """
-        vcs_base.VCSClientBase.__init__(self, path)
+        VcsClientBase.__init__(self, 'svn', path)
         with open(os.devnull, 'w') as fnull:
             try:
                 subprocess.call("svn help".split(), stdout=fnull, stderr=fnull)
@@ -59,7 +57,8 @@ class SVNClient(vcs_base.VCSClientBase):
         @return: SVN URL of the directory path (output of svn info command), or None if it cannot be determined
         """
         if self.detect_presence():
-            output = subprocess.Popen(['svn', 'info', self._path], stdout=subprocess.PIPE).communicate()[0]
+            #3305: parsing not robust to non-US locales
+            output = subprocess.Popen(['svn', 'info', self._path], stdout=subprocess.PIPE, env={"LANG":"en_US.UTF-8"}).communicate()[0]
             matches = [l for l in output.splitlines() if l.startswith('URL: ')]
             if matches:
                 return matches[0][5:]
@@ -94,10 +93,6 @@ class SVNClient(vcs_base.VCSClientBase):
             return True
         return False
 
-    def get_vcs_type_name(self):
-        return 'svn'
-
-
     def get_version(self, spec=None):
         """
         @param spec: (optional) spec can be what 'svn info --help
@@ -125,7 +120,8 @@ class SVNClient(vcs_base.VCSClientBase):
                     return '-r'+spec
             command.append('-r' + spec)
         command.append(self._path)
-        output = subprocess.Popen(command, stdout=subprocess.PIPE).communicate()[0]
+        # #3305: parsing not robust to non-US locales
+        output = subprocess.Popen(command, env={"LANG":"en_US.UTF-8"}, stdout=subprocess.PIPE).communicate()[0]
         if output != None:
             matches = [l for l in output.splitlines() if l.startswith('Revision: ')]
             if len(matches) == 1:
@@ -134,38 +130,31 @@ class SVNClient(vcs_base.VCSClientBase):
                     return '-r'+split_str[1]
         return None
 
-class SVNConfig(object):
-    """
-    Configuration information about an SVN repository for a component
-    of code. The configuration we maintain is specific to ROS
-    toolchain concepts and is not a general notion of SVN configuration.
+    def get_diff(self, basepath=None):
+        response = None
+        if basepath == None:
+            basepath = self._path
+        if self.path_exists():
+            rel_path = self._normalized_rel_path(self._path, basepath)
+            command = "cd %s; svn diff %s"%(basepath, rel_path)
+            stdout_handle = os.popen(command, "r")
+            response = stdout_handle.read()
+        if response != None and response.strip() == '':
+            response = None
+        return response
+ 
+ 
+    def get_status(self, basepath=None, untracked=False):
+        response=None
+        if basepath == None:
+            basepath = self._path
+        if self.path_exists():
+            rel_path = self._normalized_rel_path(self._path, basepath)
+            command = "cd %s; svn status %s"%(basepath, rel_path)
+            if not untracked:
+                command += " -q"
+            stdout_handle = os.popen(command, "r")
+            response = stdout_handle.read()
+        return response
 
-     * dev: where the code is developed
-     * distro_tag: a tag of the code for a specific ROS distribution
-     * release_tag: a tag of the code for a specific release
-    """
-    
-    def __init__(self):
-        self.type = 'svn'
-        self.dev = None
-        self.distro_tag = None
-        self.release_tag = None
-
-        # anonymously readable version of URLs above. Some repos have
-        # separate URLs for read-only vs. writable versions of repo
-        # and many tools need to be able to read repos without
-        # providing credentials.
-        self.anon_dev         = None
-        self.anon_distro_tag  = None
-        self.anon_release_tag = None
-
-    def __eq__(self, other):
-        return self.dev == other.dev and \
-            self.distro_tag == other.distro_tag and \
-            self.release_tag == other.release_tag and \
-            self.anon_dev == other.anon_dev and \
-            self.anon_distro_tag == other.anon_distro_tag and \
-            self.anon_release_tag == other.anon_release_tag
-
-    def __repr__(self):
-        return "{dev: '%s', distro-tag: '%s', 'release-tag': '%s', anon-dev: '%s', anon-distro-tag: '%s', anon-release-tag: '%s'}"%(self.dev, self.distro_tag, self.release_tag, self.anon_dev, self.anon_distro_tag, self.anon_release_tag)
+SVNClient = SvnClient
